#ifndef __COMPAT_KERNEL_H__
#   define __COMPAT_KERNEL_H__

/*
 * wait_for_completion and friends did not exist before 2.4.9.
 */
#if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 4, 9)

#define compat_complete_and_exit(comp, status) complete_and_exit(comp, status)

#else

/*
 * See compat_wait_for_completion in compat_completion.h.
 * exit or _exit implicitly performs an unlock_kernel, in resident code,
 * ensuring that the thread is no longer running in module code when the
 * module is unloaded.
 */
#ifdef MODULE_X86_64
#define compat_complete_and_exit(comp, status) do { \
   lock_kernel(); \
   up(comp); \
   exit(status); \
} while (0)
#else 
#define compat_complete_and_exit(comp, status) do { \
   lock_kernel(); \
   up(comp); \
   _exit(status); \
} while (0)
#endif

#endif


#endif /* __COMPAT_KERNEL_H__ */
